Learn R Programming

recodeflow (version 0.1.0)

get_var_details_row_indices: Get all variable details row indices for a variable.

Description

Get all variable details row indices for a variable.

Usage

get_var_details_row_indices(var_details_sheet, var_name)

Arguments

var_details_sheet

A data frame representing a variable details sheet.

var_name

Variable name.

Value

All variable details row indices for a variable.