get_var_details_rows: Get all variable details rows for a variable and database combination.
Description
Get all variable details rows for a variable and database combination.
Usage
get_var_details_rows(var_details_sheet, var_name, db_name)
Arguments
var_details_sheet
A data frame representing a variable details sheet.
Value
All variable details rows for the variable and database combination.