is_numeric: Check if a character object can be converted to a number.

View source: R/utils.R

is_numericR Documentation

Check if a character object can be converted to a number.

Description

Check if a character object can be converted to a number.

Usage

is_numeric(chars)

Arguments

chars

Character object.

Value

Whether 'chars' can be converted to a numeric value.


recodeflow documentation built on July 10, 2026, 1:08 a.m.