select_vars_by_role: Vars selected by role
Description
Selects variables from variables sheet based on passed roles
Usage
select_vars_by_role(roles, variables)
Arguments
roles
a vector containing a single or multiple roles to match by
variables
the variables sheet containing variable info
Value
a vector containing the variable names that match the passed roles