get_var_details_row_indices: Get all variable details row indices for a variable.
Description
Get all variable details row indices for a variable.
Usage
get_var_details_row_indices(var_details_sheet, var_name)
Arguments
var_details_sheet
A data frame representing a variable details sheet.
Value
All variable details row indices for a variable.